@@ -4,37 +4,39 @@
 ###############################################################################
 
 
+# density estimators ------------------------------------------------------
 
+## density_unbounded -------------------------------------------------------
 #' Unbounded density estimator
 #'
 #' Unbounded density estimator using [stats::density()].
-#' @template description-auto-partial
+#' @template description-auto-partial-waivable
 #'
-#' @param x numeric vector containing a sample to compute a density estimate for.
-#' @param weights optional numeric vector of weights to apply to `x`.
-#' @param n numeric: the number of grid points to evaluate the density estimator at.
-#' @param bandwidth bandwidth of the density estimator. One of:
+#' @param x <[numeric]> Sample to compute a density estimate for.
+#' @param weights <[numeric] | [NULL]> Optional weights to apply to `x`.
+#' @param n <scalar [numeric]> The number of grid points to evaluate the density estimator at.
+#' @param bandwidth <scalar [numeric] | [function] | [string][character]>
+#' Bandwidth of the density estimator. One of:
 #'   - a numeric: the bandwidth, as the standard deviation of the kernel
 #'   - a function: a function taking `x` (the sample) and returning the bandwidth
 #'   - a string: the suffix of the name of a function starting with `"bandwidth_"` that
 #'     will be used to determine the bandwidth. See [bandwidth] for a list.
-#' @param adjust numeric: the bandwidth for the density estimator is multiplied
-#' by this value. See [stats::density()].
-#' @param kernel string: the smoothing kernel to be used. This must partially
+#' @eval rd_param_density_adjust()
+#' @param kernel <[string][character]> The smoothing kernel to be used. This must partially
 #' match one of `"gaussian"`, `"rectangular"`, `"triangular"`, `"epanechnikov"`,
 #' `"biweight"`, `"cosine"`, or `"optcosine"`. See [stats::density()].
-#' @param trim Should the density estimate be trimmed to the bounds of the data?
-#' @param adapt (**very experimental**) The name and interpretation of this argument
-#' are subject to change without notice. Positive integer. If `adapt > 1`, uses
+#' @eval rd_param_density_trim()
+#' @param adapt <positive [integer]> (**very experimental**) The name and interpretation of this argument
+#' are subject to change without notice. If `adapt > 1`, uses
 #' an adaptive approach to calculate the density. First, uses the
 #' adaptive bandwidth algorithm of Abramson (1982) to determine local (pointwise)
 #' bandwidths, then groups these bandwidths into `adapt` groups, then calculates
 #' and sums the densities from each group. You can set this to a very large number
 #' (e.g. `Inf`) for a fully adaptive approach, but this will be very slow; typically
 #' something around 100 yields nearly identical results.
-#' @param na.rm Should missing (`NA`) values in `x` be removed?
+#' @param na.rm <scalar [logical]> Should missing (`NA`) values in `x` be removed?
 #' @param ... Additional arguments (ignored).
-#' @param range_only If `TRUE`, the range of the output of this density estimator
+#' @param range_only <scalar [logical]> If `TRUE`, the range of the output of this density estimator
 #' is computed and is returned in the `$x` element of the result, and `c(NA, NA)`
 #' is returned in `$y`. This gives a faster way to determine the range of the output
 #' than `density_XXX(n = 2)`.
@@ -75,8 +77,8 @@
 #' @export
 density_unbounded = auto_partial(name = "density_unbounded", function(
   x, weights = NULL,
-  n = 512, bandwidth = "dpi", adjust = 1, kernel = "gaussian",
-  trim = FALSE,
+  n = 501, bandwidth = "dpi", adjust = 1, kernel = "gaussian",
+  trim = TRUE,
   adapt = 1,
   na.rm = FALSE,
   ...,
@@ -116,15 +118,17 @@ density_unbounded = auto_partial(name = "density_unbounded", function(
 })
 
 
+## density_bounded -------------------------------------------------------
 #' Bounded density estimator using the reflection method
 #'
 #' Bounded density estimator using the reflection method.
-#' @template description-auto-partial
+#' @template description-auto-partial-waivable
 #'
 #' @inheritParams density_unbounded
-#' @param bounds length-2 vector of min and max bounds. If a bound is `NA`, then
+#' @param bounds <length-2 [numeric]> Min and max bounds. If a bound is `NA`, then
 #' that bound is estimated from the data using the method specified by `bounder`.
-#' @param bounder Method to use to find missing (`NA`) `bounds`. A function that
+#' @param bounder <[function] | [string][character]> Method to use to find missing
+#' (`NA`) `bounds`. A function that
 #' takes a numeric vector of values and returns a length-2 vector of the estimated
 #' lower and upper bound of the distribution. Can also be a string giving the
 #' suffix of the name of such a function that starts with `"bounder_"`. Useful
@@ -188,8 +192,8 @@ density_unbounded = auto_partial(name = "density_unbounded", function(
 #' @export
 density_bounded = auto_partial(name = "density_bounded", function(
   x, weights = NULL,
-  n = 512, bandwidth = "dpi", adjust = 1, kernel = "gaussian",
-  trim = FALSE, bounds = c(NA, NA), bounder = "cdf",
+  n = 501, bandwidth = "dpi", adjust = 1, kernel = "gaussian",
+  trim = TRUE, bounds = c(NA, NA), bounder = "cdf",
   adapt = 1,
   na.rm = FALSE,
   ...,
@@ -254,50 +258,28 @@ density_bounded = auto_partial(name = "density_bounded", function(
 })
 
 
+## density_histogram -------------------------------------------------------
 #' Histogram density estimator
 #'
 #' Histogram density estimator.
-#' @template description-auto-partial
+#' @template description-auto-partial-waivable
 #'
-#' @param x numeric vector containing a sample to compute a density estimate for.
-#' @param weights optional numeric vector of weights to apply to `x`.
-#' @param breaks Determines the breakpoints defining bins. Defaults to `"Scott"`.
-#' Similar to (but not exactly the same as) the `breaks` argument to [graphics::hist()].
-#' One of:
-#'   - A scalar (length-1) numeric giving the number of bins
-#'   - A vector numeric giving the breakpoints between histogram bins
-#'   - A function taking `x` and `weights` and returning either the
-#'     number of bins or a vector of breakpoints
-#'   - A string giving the suffix of a function that starts with
-#'     `"breaks_"`. \pkg{ggdist} provides weighted implementations of the
-#'     `"Sturges"`, `"Scott"`, and `"FD"` break-finding algorithms from
-#'     [graphics::hist()], as well as [breaks_fixed()] for manually setting
-#'     the bin width. See [breaks].
-#'
-#' For example, `breaks = "Sturges"` will use the [breaks_Sturges()] algorithm,
-#' `breaks = 9` will create 9 bins, and `breaks = breaks_fixed(width = 1)` will
-#' set the bin width to `1`.
-#' @param align Determines how to align the breakpoints defining bins. Default
-#' (`"none"`) performs no alignment. One of:
-#'   - A scalar (length-1) numeric giving an offset that is subtracted from the breaks.
-#'     The offset must be between `0` and the bin width.
-#'   - A function taking a sorted vector of `breaks` (bin edges) and returning
-#'     an offset to subtract from the breaks.
-#'   - A string giving the suffix of a function that starts with
-#'     `"align_"` used to determine the alignment, such as [align_none()],
-#'     [align_boundary()], or [align_center()].
-#'
-#' For example, `align = "none"` will provide no alignment, `align = align_center(at = 0)`
-#' will center a bin on `0`, and `align = align_boundary(at = 0)` will align a bin
-#' edge on `0`.
-#' @param outline_bars Should outlines in between the bars (i.e. density values of
+#' @inheritParams density_unbounded
+#' @eval rd_param_density_breaks()
+#' @eval rd_param_density_align()
+#' @param outline_bars <scalar [logical]> Should outlines in between the bars (i.e. density values of
 #' 0) be included?
-#' @param na.rm Should missing (`NA`) values in `x` be removed?
-#' @param ... Additional arguments (ignored).
-#' @param range_only If `TRUE`, the range of the output of this density estimator
-#' is computed and is returned in the `$x` element of the result, and `c(NA, NA)`
-#' is returned in `$y`. This gives a faster way to determine the range of the output
-#' than `density_XXX(n = 2)`.
+#' @param right_closed <scalar [logical]> Should the right edge of each bin be closed? For
+#' a bin with endpoints \eqn{L} and \eqn{U}:
+#'  - if `TRUE`, use \eqn{(L, U]}: the interval containing all \eqn{x} such that \eqn{L < x \le U}.
+#'  - if `FALSE`, use \eqn{[L, U)}: the interval containing all \eqn{x} such that \eqn{L \le x < U}.
+#'
+#' Equivalent to the `right` argument of [hist()] or the `left.open` argument of [findInterval()].
+#' @param outermost_closed <scalar [logical]> Should values on the edges of the outermost (first
+#' or last) bins always be included in those bins? If `TRUE`, the first edge (when `right_closed = TRUE`)
+#' or the last edge (when `right_closed = FALSE`) is treated as closed.
+#'
+#' Equivalent to the `include.lowest` argument of [hist()] or the `rightmost.closed` argument of [findInterval()].
 #' @template returns-density
 #' @family density estimators
 #' @examples
@@ -334,6 +316,8 @@ density_histogram = auto_partial(name = "density_histogram", function(
   breaks = "Scott",
   align = "none",
   outline_bars = FALSE,
+  right_closed = TRUE,
+  outermost_closed = TRUE,
   na.rm = FALSE,
   ...,
   range_only = FALSE
@@ -341,7 +325,11 @@ density_histogram = auto_partial(name = "density_histogram", function(
   x_label = as_label(enexpr(x))
   x = check_na(x, na.rm)
 
-  h = weighted_hist(x, weights = weights, breaks = breaks, align = align)
+  h = weighted_hist(
+    x, weights = weights,
+    breaks = breaks, align = align,
+    right_closed = right_closed, outermost_closed = outermost_closed
+  )
   input_1 = h$breaks[-length(h$breaks)]  # first edge of bin
   input_2 = h$breaks[-1]                 # second edge of bin
   input_ = (input_1 + input_2)/2   # center of bin
@@ -356,7 +344,7 @@ density_histogram = auto_partial(name = "density_histogram", function(
   # work as expected if 1 is a bin edge.
   eps = min(diff(h$breaks)/4, 2*.Machine$double.eps)
 
-  if (outline_bars) {
+  if (isTRUE(outline_bars)) {
     # have to return to 0 in between each bar so that bar outlines are drawn
     input = as.vector(rbind(input_1, input_1, input_1 + eps, input_, input_, input_2 - eps, input_2, input_2))
     pdf = as.vector(rbind(0, h$density, h$density, h$density, h$density, h$density, h$density, 0))
@@ -370,31 +358,49 @@ density_histogram = auto_partial(name = "density_histogram", function(
     cdf = as.vector(rbind(cdf_1, cdf_1, cdf_1, cdf_, cdf_2, cdf_2))
   }
 
-  structure(list(
-    x = input,
-    y = pdf,
-    bw = if (h$equidist) diff(h$breaks[1:2]) else mean(diff(h$breaks)),
-    n = length(x),
-    # need to apply get_expr over match.call() instead of just using match.call()
-    # to remove tildes from the call created by partial application
-    call = as.call(lapply(match.call(), get_expr)),
-    data.name = x_label,
-    has.na = FALSE,
-    cdf = cdf
-  ), class = "density")
+  structure(
+    list(
+      x = input,
+      y = pdf,
+      bw = if (h$equidist) diff(h$breaks[1:2]) else mean(diff(h$breaks)),
+      n = length(x),
+      # need to apply get_expr over match.call() instead of just using match.call()
+      # to remove tildes from the call created by partial application
+      call = as.call(lapply(match.call(), get_expr)),
+      data.name = x_label,
+      has.na = FALSE,
+      cdf = cdf
+    ),
+    class = c("ggdist_density", "density")
+  )
 })
 
 
+# density object methods --------------------------------------------------
+
+#' @export
+plot.ggdist_density = function(x, ..., ylim = c(0, NA)) {
+  if (is.null(ylim)) {
+    ylim = range(x$y)
+  } else {
+    missing_limit = is.na(ylim)
+    ylim[missing_limit] = range(x$y)[missing_limit]
+  }
+  NextMethod(ylim = ylim)
+}
+
+
 # bandwidth estimators ----------------------------------------------------
 
+## bandwidth_nrd0 ----------------------------------------------------------
 #' Bandwidth estimators
 #'
 #' Bandwidth estimators for densities, used in the `bandwidth` argument
 #' to density functions (e.g. [density_bounded()], [density_unbounded()]).
-#' @template description-auto-partial
+#' @template description-auto-partial-waivable
 #'
 #' @inheritDotParams stats::bw.SJ
-#' @param x A numeric vector giving a sample.
+#' @param x <[numeric]> Vector containing a sample.
 #' @details
 #' These are loose wrappers around the corresponding `bw.`-prefixed functions
 #' in \pkg{stats}. See, for example, [bw.SJ()].
@@ -402,6 +408,14 @@ density_histogram = auto_partial(name = "density_histogram", function(
 #' [bandwidth_dpi()], which is the default bandwidth estimator in \pkg{ggdist},
 #' is the Sheather-Jones direct plug-in estimator, i.e. `bw.SJ(..., method = "dpi")`.
 #'
+#' With the exception of [bandwidth_nrd0()], these estimators may fail in some
+#' cases, often when a sample contains many duplicates. If they do they will
+#' automatically fall back to [bandwidth_nrd0()] with a warning. However, these
+#' failures are typically symptomatic of situations where you should not want to
+#' use a kernel density estimator in the first place (e.g. data with duplicates
+#' and/or discrete data). In these cases consider using a dotplot ([geom_dots()])
+#' or histogram ([density_histogram()]) instead.
+#'
 #' @returns A single number giving the bandwidth
 #' @seealso [density_bounded()], [density_unbounded()].
 #' @name bandwidth
@@ -411,6 +425,7 @@ bandwidth_nrd0 = auto_partial(name = "bandwidth_nrd0", function(x, ...) {
   bw.nrd0(x)
 })
 
+## bandwidth_nrd ----------------------------------------------------------
 #' @rdname bandwidth
 #' @importFrom stats bw.nrd
 #' @export
@@ -418,6 +433,7 @@ bandwidth_nrd = auto_partial(name = "bandwidth_nrd", function(x, ...) {
   bw_fallback(bw.nrd, x, ..., call = call("bandwidth_nrd"))
 })
 
+## bandwidth_ucv ----------------------------------------------------------
 #' @rdname bandwidth
 #' @importFrom stats bw.ucv
 #' @export
@@ -425,6 +441,7 @@ bandwidth_ucv = auto_partial(name = "bandwidth_ucv", function(x, ...) {
   bw_fallback(bw.ucv, x, ..., call = call("bandwidth_ucv"))
 })
 
+## bandwidth_bcv ----------------------------------------------------------
 #' @rdname bandwidth
 #' @importFrom stats bw.bcv
 #' @export
@@ -432,6 +449,7 @@ bandwidth_bcv = auto_partial(name = "bandwidth_bcv", function(x, ...) {
   bw_fallback(bw.bcv, x, ..., call = call("bandwidth_bcv"))
 })
 
+## bandwidth_SJ ----------------------------------------------------------
 #' @rdname bandwidth
 #' @importFrom stats bw.SJ
 #' @export
@@ -439,6 +457,7 @@ bandwidth_SJ = auto_partial(name = "bandwidth_SJ", function(x, ...) {
   bw_fallback(bw.SJ, x, ..., call = call("bandwidth_SJ"))
 })
 
+## bandwidth_dpi ----------------------------------------------------------
 #' @rdname bandwidth
 #' @export
 bandwidth_dpi = auto_partial(name = "bandwidth_dpi", function(x, ...) {
@@ -454,7 +473,7 @@ bandwidth_dpi = auto_partial(name = "bandwidth_dpi", function(x, ...) {
 #' @importFrom stats bw.nrd0 kmeans
 .density_adaptive = function(
   x, weights = NULL,
-  n = 512,
+  n = 501,
   bw = bw.nrd0(x),
   adapt = 1,
   kernel = "gaussian",
@@ -468,12 +487,14 @@ bandwidth_dpi = auto_partial(name = "bandwidth_dpi", function(x, ...) {
 
   if (adapt == 1) {
     # quick exit: just return the non-adaptive density
-    return(density(
+    d = density(
       x, weights = weights,
       n = n, bw = bw,
       kernel = kernel,
       from = from, to = to
-    ))
+    )
+    class(d) = c("ggdist_density", "density")
+    return(d)
   }
 
   # determine local adaptive bandwidth
@@ -516,15 +537,18 @@ bandwidth_dpi = auto_partial(name = "bandwidth_dpi", function(x, ...) {
   })
   f = rowSums(vapply(densities, `[[`, "y", FUN.VALUE = numeric(n)))
 
-  structure(list(
-    x = densities[[1]]$x,
-    y = f,
-    bw = bw,
-    n = n_x,
-    call = match.call(),
-    data.name = "x",
-    has.na = FALSE
-  ), class = "density")
+  structure(
+    list(
+      x = densities[[1]]$x,
+      y = f,
+      bw = bw,
+      n = n_x,
+      call = match.call(),
+      data.name = "x",
+      has.na = FALSE
+    ),
+    class = c("ggdist_density", "density")
+  )
 }
 
 get_local_bandwidth = function(x, bandwidth, kernel, n) {
