@@ -21,7 +21,7 @@
 #' thickness function.
 #' @inheritParams geom_slabinterval
 #' @return A [ggplot2::Geom] representing a spike geometry which can
-#' be added to a [ggplot()] object.
+#' be added to a [`ggplot()`][ggplot2::ggplot] object.
 #' rd_slabinterval_aesthetics(geom_name),
 #' @seealso
 #' See [stat_spike()] for the stat version, intended for
@@ -74,19 +74,22 @@ NULL
 
 # drawing functions -------------------------------------------------------
 
-draw_slabs_spike = function(self, s_data, panel_params, coord,
-  orientation, normalize, na.rm,
-  arrow = NULL,
-  ...
+draw_slabs_spike = function(
+  self, s_data, panel_params, coord, orientation,
+  ...,
+  na.rm,
+  arrow = NULL
 ) {
   define_orientation_variables(orientation)
 
   # remove missing values - unlike slabinterval, thickness NAs not allowed here
   s_data = ggplot2::remove_missing(s_data, na.rm, "thickness", name = "geom_spike")
 
-  s_data = self$override_slab_aesthetics(rescale_slab_thickness(
-    s_data, orientation, normalize, na.rm, name = "geom_spike"
-  ))
+  subguide_params = NULL
+  c(s_data, subguide_params) %<-% rescale_slab_thickness(
+    s_data, orientation, na.rm, name = "geom_spike"
+  )
+  s_data = self$override_slab_aesthetics(s_data)
 
   s_data[[xend]] = s_data[[x]]
   s_data[[y]] = case_when_side(s_data$side, orientation,
@@ -152,8 +155,8 @@ GeomSpike = ggproto("GeomSpike", GeomSlab,
   ), GeomSlab$hidden_aes),
 
   override_slab_aesthetics = function(self, s_data) {
-    s_data$colour = apply_colour_ramp(s_data[["colour"]], s_data[["colour_ramp"]])
-    s_data$fill = apply_colour_ramp(s_data[["fill"]], s_data[["fill_ramp"]])
+    s_data$colour = ramp_colours(s_data[["colour"]], s_data[["colour_ramp"]])
+    s_data$fill = ramp_colours(s_data[["fill"]], s_data[["fill_ramp"]])
     s_data
   },
 
@@ -164,16 +167,17 @@ GeomSpike = ggproto("GeomSpike", GeomSlab,
 
   param_docs = defaults(list(
     # SLAB PARAMS
-    arrow = '[grid::arrow()] giving the arrow heads to use on the spike, or `NULL` for no arrows.'
+    arrow = '<[arrow] | [NULL]> Type of arrow heads to use on the spike, or `NULL` for no arrows.'
   ), GeomSlab$param_docs),
 
   default_params = defaults(list(
-    arrow = NULL
+    subguide = "spike"
   ), GeomSlab$default_params),
 
-  hidden_params = union(c(
-    "fill_type"
-  ), GeomSlab$hidden_params),
+  hidden_params = setdiff(
+    union("fill_type", GeomSlab$hidden_params),
+    "arrow"
+  ),
 
 
   ## other methods -----------------------------------------------------------
@@ -181,8 +185,9 @@ GeomSpike = ggproto("GeomSpike", GeomSlab,
   draw_key_slab = function(self, data, key_data, params, size) {
     s_key_data = self$override_slab_aesthetics(key_data)
 
-    spike_key = if (any(!is.na(data[c("colour","colour_ramp","alpha","linewidth","linetype")]))) {
-      line_key = if(params$orientation %in% c("y", "horizontal")) {
+    show_spike_when_present = c("colour", "colour_ramp", "alpha", "linewidth", "linetype")
+    spike_key = if (!all(is.na(data[show_spike_when_present]))) {
+      line_key = if (params$orientation %in% c("y", "horizontal")) {
         draw_key_vpath
       } else {
         draw_key_path
@@ -191,12 +196,12 @@ GeomSpike = ggproto("GeomSpike", GeomSlab,
     }
 
     point_key = if (
-      !all(is.na(s_key_data$size) | s_key_data$size == 0) && (
-        any(!is.na(data[c("size","stroke","shape","alpha")])) ||
-        # only draw point for `fill` aesthetic if a shape that has a fill colour is used
-        (any(!is.na(data[c("fill","fill_ramp")])) && length(intersect(data$shape, c(21:25))) > 0) ||
-        (any(!is.na(data[c("fill","fill_ramp")])) && length(intersect(data$shape, c(21:25))) > 0)
-      )
+      !all(is.na(s_key_data$size) | s_key_data$size == 0) &&
+        (
+          !all(is.na(data[c("size", "stroke", "shape", "alpha")])) ||
+            # only draw point for `fill` aesthetic if a shape that has a fill colour is used
+            (!all(is.na(data[c("fill", "fill_ramp")])) && length(intersect(data$shape, 21:25)) > 0)
+        )
     ) {
       draw_key_point(s_key_data, params, size)
     }
