@@ -37,7 +37,7 @@
 #' intervals relative to their slabs when dodging.
 #'
 #' @inheritParams ggplot2::position_dodge
-#' @param justification Justification of the point position (`x`/`y`) relative
+#' @param justification <scalar [numeric]> Justification of the point position (`x`/`y`) relative
 #'   to its bounds (`xmin`/`xmax` or `ymin`/`ymax`), where `0` indicates
 #'   bottom/left justification and `1` indicates top/right justification
 #'   (depending on `orientation`). This is only used if `xmin`/`xmax`/`ymin`/`ymax`
@@ -120,7 +120,7 @@
 #'
 #'
 #' @export
-position_dodgejust <- function(width = NULL, preserve = c("total", "single"), justification = NULL) {
+position_dodgejust = function(width = NULL, preserve = c("total", "single"), justification = NULL) {
   ggproto(NULL, PositionDodgejust,
     width = width,
     preserve = match.arg(preserve),
@@ -132,7 +132,7 @@ position_dodgejust <- function(width = NULL, preserve = c("total", "single"), ju
 #' @format NULL
 #' @usage NULL
 #' @export
-PositionDodgejust <- ggproto("PositionDodgejust", Position,
+PositionDodgejust = ggproto("PositionDodgejust", Position,
   width = NULL,
   preserve = "total",
   justification = NULL,
@@ -197,7 +197,7 @@ pos_dodgejust = function(df, width, n = NULL) {
 
   # Find the center for each group, then use that to calculate xmin and xmax
   max_width = max(x_width)
-  df$x = df$x + width * ((groupidx - 0.5) / n - .5)
+  df$x = df$x + width * ((groupidx - 0.5) / n - 0.5)
   df$xmin = df$x - max_width / n / 2
   df$xmax = df$x + max_width / n / 2
 
@@ -261,12 +261,12 @@ collide = function(
   intervals = as.numeric(t(unique(data[c("xmin", "xmax")])))
   intervals = intervals[!is.na(intervals)]
 
-  if (length(unique(intervals)) > 1 & any(diff(scale(intervals)) < -1e-6)) {
+  if (length(unique(intervals)) > 1 && any(diff(scale(intervals)) < -1e-6)) {
     warning0(paste0(name, " requires non-overlapping ", x_name, " intervals"))
   }
 
   # workaround so that mapped_discrete columns can be combined with numerics
-  xy_cols = intersect(c("x","y","xmin","xmax","ymin","ymax"), names(data))
+  xy_cols = intersect(c("x", "y", "xmin", "xmax", "ymin", "ymax"), names(data))
   data[xy_cols] = lapply(data[xy_cols], as.numeric)
 
   if (!is.null(data$ymax)) {
