@@ -16,19 +16,19 @@ compute_limits_slabinterval = function(
 ) {
   dist = check_one_dist(data$dist)
   if (distr_is_missing(dist)) {
-    return(data.frame(.lower = NA, .upper = NA))
+    return(data_frame0(.lower = NA, .upper = NA))
   }
 
   if (distr_is_factor_like(dist)) {
     # limits on factor-like dists are determined by the scale, which will
     # have been set earlier (in layer_slabinterval()), so we don't have to
     # do it here
-    return(data.frame(.lower = NA, .upper = NA))
+    return(data_frame0(.lower = NA, .upper = NA))
   }
 
   if (distr_is_constant(dist)) {
     .median = distr_quantile(dist)(0.5)
-    return(data.frame(.lower = .median, .upper = .median))
+    return(data_frame0(.lower = .median, .upper = .median))
   }
 
   if (distr_is_sample(dist)) {
@@ -57,7 +57,7 @@ compute_limits_slabinterval = function(
   lower_limit = min(quantile_fun(p_limits[[1]]))
   upper_limit = max(quantile_fun(p_limits[[2]]))
 
-  data.frame(
+  data_frame0(
     .lower = lower_limit,
     .upper = upper_limit
   )
@@ -74,7 +74,7 @@ compute_limits_sample = function(x, trans, trim, adjust, ..., density = "bounded
   # determine limits of data based on the density estimator
   x = trans$transform(x)
   x_range = range(density(x, n = 2, range_only = TRUE, trim = trim, adjust = adjust, weights = weights)$x)
-  data.frame(
+  data_frame0(
     .lower = trans$inverse(x_range[[1]]),
     .upper = trans$inverse(x_range[[2]])
   )
@@ -94,7 +94,7 @@ compute_slab_slabinterval = function(
   dist = data$dist
   # TODO: add support for multivariate distributions
   if (distr_is_missing(dist) || distr_is_multivariate(dist)) {
-    return(data.frame(.input = NA_real_, f = NA_real_, n = NA_integer_))
+    return(data_frame0(.input = NA_real_, f = NA_real_, n = NA_integer_))
   }
 
   # calculate pdf and cdf
@@ -142,7 +142,7 @@ compute_slab_slabinterval = function(
       # work as expected if 1 is a bin edge.
       eps = 2*.Machine$double.eps
 
-      if (outline_bars) {
+      if (isTRUE(outline_bars)) {
         # have to return to 0 in between each bar so that bar outlines are drawn
         input = as.vector(rbind(input_1, input_1, input_1 + eps, input_, input_, input_2 - eps, input_2, input_2))
         pdf = as.vector(rbind(0, pdf, pdf, pdf, pdf, pdf, pdf, 0))
@@ -167,7 +167,7 @@ compute_slab_slabinterval = function(
     cdf = cdf_fun(input)
   }
 
-  data.frame(
+  data_frame0(
     .input = input,
     f = get_slab_function(slab_type, list(pdf = pdf, cdf = cdf)),
     pdf = pdf,
@@ -191,7 +191,6 @@ compute_slab_sample = function(
   ...,
   weights = NULL
 ) {
-
   if (is.integer(x) || inherits(x, "mapped_discrete")) {
     # discrete variables are always displayed as histograms
     slab_type = "histogram"
@@ -207,7 +206,7 @@ compute_slab_sample = function(
     breaks = breaks, align = align, outline_bars = outline_bars,
     weights = weights
   )
-  slab_df = data.frame(
+  slab_df = data_frame0(
     .input = trans$inverse(d$x),
     pdf = d$y,
     cdf = d$cdf %||% weighted_ecdf(x, weights = weights)(d$x)
@@ -221,7 +220,7 @@ compute_slab_sample = function(
   if (expand[[1]]) {
     input_below_slab = input[input < min(slab_df$.input) - .Machine$double.eps]
     if (length(input_below_slab) > 0) {
-      slab_df = rbind(data.frame(
+      slab_df = rbind(data_frame0(
         .input = input_below_slab,
         pdf = 0,
         cdf = 0
@@ -231,7 +230,7 @@ compute_slab_sample = function(
   if (expand[[2]]) {
     input_above_slab = input[input > max(slab_df$.input) + .Machine$double.eps]
     if (length(input_above_slab) > 0) {
-      slab_df = rbind(slab_df, data.frame(
+      slab_df = rbind(slab_df, data_frame0(
         .input = input_above_slab,
         pdf = 0,
         cdf = 1
@@ -255,10 +254,10 @@ compute_interval_slabinterval = function(
   .width, na.rm,
   ...
 ) {
-  if (is.null(point_interval)) return(data.frame())
+  if (is.null(point_interval)) return(data_frame0())
   dist = data$dist
   if (distr_is_missing(dist)) {
-    return(data.frame(.value = NA_real_, .lower = NA_real_, .upper = NA_real_, .width = .width))
+    return(data_frame0(.value = NA_real_, .lower = NA_real_, .upper = NA_real_, .width = .width))
   }
 
   distr_point_interval(dist, point_interval, trans = trans, .width = .width, na.rm = na.rm)
@@ -303,27 +302,19 @@ compute_interval_slabinterval = function(
 #'
 #' @inheritParams geom_slabinterval
 #' @inheritParams density_histogram
-#' @param geom Use to override the default connection between
-#' [stat_slabinterval()] and [geom_slabinterval()]
-#' @param slab_type (deprecated) The type of slab function to calculate: probability density (or mass) function
-#' (`"pdf"`), cumulative distribution function (`"cdf"`), or complementary CDF (`"ccdf"`). Instead of using
-#' `slab_type` to change `f` and then mapping `f` onto an aesthetic, it is now recommended to simply map the
-#' corresponding computed variable (e.g. `pdf`, `cdf`, or  `1 - cdf`) directly onto the desired aesthetic.
-#' @param p_limits Probability limits (as a vector of size 2) used to determine the lower and upper
-#' limits of *theoretical* distributions (distributions from *samples* ignore this parameter and determine
-#' their limits based on the limits of the sample). E.g., if this is `c(.001, .999)`, then a slab is drawn
+#' @param geom <[Geom][ggplot2::Geom] | [string][character]> Use to override the
+#' default connection between [stat_slabinterval()] and [geom_slabinterval()].
+#' @param p_limits <length-2 [numeric]> Probability limits. Used to determine the lower and upper
+#' limits of *analytical* distributions (distributions from *samples* ignore this parameter and determine
+#' their limits based on the limits of the sample and the value of the `trim` parameter).
+#' E.g., if this is `c(.001, .999)`, then a slab is drawn
 #' for the distribution from the quantile at `p = .001` to the quantile at `p = .999`. If the lower
 #' (respectively upper) limit is `NA`, then the lower (upper) limit will be the minimum (maximum) of the
 #' distribution's support if it is finite, and `0.001` (`0.999`) if it is not finite. E.g., if
 #' `p_limits` is `c(NA, NA)`, on a gamma distribution the effective value of `p_limits` would be
 #' `c(0, .999)` since the gamma distribution is defined on `(0, Inf)`; whereas on a normal distribution
 #' it would be equivalent to `c(.001, .999)` since the normal distribution is defined on `(-Inf, Inf)`.
-#' @param outline_bars For sample data (if `density` is `"histogram"`) and for discrete analytical
-#' distributions (whose slabs are drawn as histograms), determines
-#' if outlines in between the bars are drawn when the `slab_color` aesthetic is used. If `FALSE`
-#' (the default), the outline is drawn only along the tops of the bars; if `TRUE`, outlines in between
-#' bars are also drawn. See [density_histogram()].
-#' @param density Density estimator for sample data. One of:
+#' @param density <[function] | [string][character]> Density estimator for sample data. One of:
 #'  - A function which takes a numeric vector and returns a list with elements
 #'    `x` (giving grid points for the density estimator) and `y` (the
 #'    corresponding densities). \pkg{ggdist} provides a family of functions
@@ -334,37 +325,48 @@ compute_interval_slabinterval = function(
 #'    or `"histogram"` for [density_histogram()].
 #'    Defaults to `"bounded"`, i.e. [density_bounded()], which estimates the bounds from
 #'    the data and then uses a bounded density estimator based on the reflection method.
-#' @param adjust Passed to `density`: the bandwidth for the density estimator for sample data
-#' is adjusted by multiplying it by this value. See e.g. [density_bounded()] for more information.
-#' Default (`waiver()`) defers to the default of the density estimator, which is usually `1`.
-#' @param trim For sample data, should the density estimate be trimmed to the range of the
-#' data? Passed on to the density estimator; see the `density` parameter. Default `TRUE`.
-#' @param expand For sample data, should the slab be expanded to the limits of the scale? Default `FALSE`.
-#' Can be length two to control expansion to the lower and upper limit respectively.
-#' @param limits Manually-specified limits for the slab, as a vector of length two. These limits are combined with those
-#' computed based on `p_limits` as well as the limits defined by the scales of the plot to determine the
-#' limits used to draw the slab functions: these limits specify the maximal limits; i.e., if specified, the limits
-#' will not be wider than these (but may be narrower). Use `NA` to leave a limit alone; e.g.
-#' `limits = c(0, NA)` will ensure that the lower limit does not go below 0, but let the upper limit
-#' be determined by either `p_limits` or the scale settings.
-#' @param n Number of points at which to evaluate the function that defines the slab.
-#' @param point_interval A function from the [point_interval()] family (e.g., `median_qi`,
-#'   `mean_qi`, `mode_hdi`, etc), or a string giving the name of a function from that family
-#'   (e.g., `"median_qi"`, `"mean_qi"`, `"mode_hdi"`, etc; if a string, the caller's environment is searched
-#'   for the function, followed by the \pkg{ggdist} environment). This function determines the point summary
-#'   (typically mean, median, or mode) and interval type (quantile interval, `qi`;
-#'   highest-density interval, `hdi`; or highest-density continuous interval, `hdci`). Output will
-#'   be converted to the appropriate `x`- or `y`-based aesthetics depending on the value of `orientation`.
-#'   See the [point_interval()] family of functions for more information.
-#' @param .width The `.width` argument passed to `point_interval`: a vector of probabilities to use
-#' that determine the widths of the resulting intervals. If multiple probabilities are provided,
+#' @eval rd_param_density_adjust(passed_to = "density_bounded")
+#' @eval rd_param_density_trim(passed_to = "density_bounded")
+#' @eval rd_param_density_breaks(passed_to = "density_histogram")
+#' @eval rd_param_density_align(passed_to = "density_histogram")
+#' @param outline_bars <scalar [logical] | [waiver]> Passed to `density` (e.g. [density_histogram()]) and also
+#' used for discrete analytical distributions (whose slabs are drawn as histograms). Determines
+#' if outlines in between the bars are drawn. If [waiver()] or `FALSE`
+#' (the default), the outline is drawn only along the tops of the bars. If `TRUE`, outlines in between
+#' bars are also drawn (though you may have to set the `slab_color` or `color` aesthetic to
+#' see the outlines).
+#' @param expand <[logical]> For sample data, should the slab be expanded to the limits of the scale? Default `FALSE`.
+#' Can be a length-two logical vector to control expansion to the lower and upper limit respectively.
+#' @param limits <length-2 [numeric]> Manually-specified limits for the slab, as
+#' a vector of length two. These limits are combined with those computed based on
+#' `p_limits` as well as the limits defined by the scales of the plot to
+#' determine the limits used to draw the slab functions: these limits specify
+#' the maximal limits; i.e., if specified, the limits will not be wider than
+#' these (but may be narrower). Use `NA` to leave a limit alone; e.g.
+#' `limits = c(0, NA)` will ensure that the lower limit does not go below 0, but
+#' let the upper limit be determined by either `p_limits` or the scale settings.
+#' @param n <scalar [numeric]> Number of points at which to evaluate the function that defines the slab. Also
+#' passed to `density` (e.g. [density_bounded()]). Default `waiver()` uses the value `501`
+#' for analytical distributions and defers to the default of the density estimator for
+#' sample-based distributions, which is also usually `501`.
+#' @param point_interval <[function] | [string][character]> A function from the [point_interval()] family
+#' (e.g., `median_qi`, `mean_qi`, `mode_hdi`, etc), or a string giving the name of a function from that family
+#' (e.g., `"median_qi"`, `"mean_qi"`, `"mode_hdi"`, etc; if a string, the caller's environment is searched
+#' for the function, followed by the \pkg{ggdist} environment). This function determines the point summary
+#' (typically mean, median, or mode) and interval type (quantile interval, `qi`;
+#' highest-density interval, `hdi`; or highest-density continuous interval, `hdci`). Output will
+#' be converted to the appropriate `x`- or `y`-based aesthetics depending on the value of `orientation`.
+#' See the [point_interval()] family of functions for more information.
+#' @param .width <[numeric]> The `.width` argument passed to `point_interval`: a vector of probabilities
+#' to use that determine the widths of the resulting intervals. If multiple probabilities are provided,
 #' multiple intervals per group are generated, each with a different probability interval (and
 #' value of the corresponding `.width` and `level` generated variables).
-#' @param show.legend Should this layer be included in the legends? Default is `c(size = FALSE)`, unlike most geoms,
-#' to match its common use cases. `FALSE` hides all legends, `TRUE` shows all legends, and `NA` shows only
-#' those that are mapped (the default for most geoms).
+#' @param show.legend <[logical]> Should this layer be included in the legends? Default is `c(size = FALSE)`,
+#' unlike most geoms, to match its common use cases. `FALSE` hides all legends, `TRUE` shows all legends,
+#' and `NA` shows only those that are mapped (the default for most geoms). It can also be a named logical
+#' vector to finely select the aesthetics to display.
 #' @return A [ggplot2::Stat] representing a slab or combined slab+interval geometry which can
-#' be added to a [ggplot()] object.
+#' be added to a [`ggplot()`][ggplot2::ggplot] object.
 #' @seealso See [geom_slabinterval()] for more information on the geom these stats
 #' use by default and some of the options it has.
 #' See `vignette("slabinterval")` for a variety of examples of use.
@@ -457,12 +459,15 @@ StatSlabinterval = ggproto("StatSlabinterval", AbstractStatSlabinterval,
     (when `orientation = "vertical"` with sample data).',
     weight = 'When using samples (i.e. the `x` and `y` aesthetics, not `xdist` or `ydist`), optional
     weights to be applied to each draw.',
-    xdist = 'When using analytical distributions, distribution to map on the x axis: a \\pkg{distributional}
-    object (e.g. [dist_normal()]) or a [posterior::rvar()] object.',
-    ydist = 'When using analytical distributions, distribution to map on the y axis: a \\pkg{distributional}
-    object (e.g. [dist_normal()]) or a [posterior::rvar()] object.',
+    xdist = 'When using analytical distributions, distribution to map on the x axis:
+    a \\pkg{distributional} object (e.g. [`dist_normal()`][distributional::dist_normal])
+    or a [posterior::rvar()] object.',
+    ydist = 'When using analytical distributions, distribution to map on the y axis:
+    a \\pkg{distributional} object (e.g. [`dist_normal()`][distributional::dist_normal])
+    or a [posterior::rvar()] object.',
     dist = 'When using analytical distributions, a name of a distribution (e.g. `"norm"`), a
-    \\pkg{distributional} object (e.g. [dist_normal()]), or a [posterior::rvar()] object. See **Details**.',
+    \\pkg{distributional} object (e.g. [`dist_normal()`][distributional::dist_normal]), or a
+    [posterior::rvar()] object. See **Details**.',
     args = 'Distribution arguments (`args` or `arg1`, ... `arg9`). See **Details**.'
   ), AbstractStatSlabinterval$aes_docs),
 
@@ -494,11 +499,11 @@ StatSlabinterval = ggproto("StatSlabinterval", AbstractStatSlabinterval,
     p_limits = c(NA, NA),
     density = "bounded",
     adjust = waiver(),
-    trim = TRUE,
-    expand = FALSE,
+    trim = waiver(),
     breaks = waiver(),
-    align = "none",
-    outline_bars = FALSE,
+    align = waiver(),
+    outline_bars = waiver(),
+    expand = FALSE,
 
     point_interval = "median_qi",
 
@@ -506,6 +511,8 @@ StatSlabinterval = ggproto("StatSlabinterval", AbstractStatSlabinterval,
     slab_type = NULL   # deprecated, set by default_slab_type (below)
   ), AbstractStatSlabinterval$default_params),
 
+  hidden_params = union("slab_type", AbstractStatSlabinterval$hidden_params),
+
   layer_function = "layer_slabinterval",
 
   # overrides slab_type in setup_params() when slab_type is NULL (the default).
@@ -547,7 +554,7 @@ StatSlabinterval = ggproto("StatSlabinterval", AbstractStatSlabinterval,
 
       # convert character/factor dist aesthetic into distributional objects
       arg_cols = names(data)[startsWith(names(data), "arg")]
-      data$dist = pmap_(data[, c("dist", arg_cols)], function(dist, ...) {
+      data$dist = pmap_(data[, c("dist", arg_cols), drop = FALSE], function(dist, ...) {
         if (is.na(dist)) {
           dist_missing()
         } else {
@@ -585,10 +592,10 @@ StatSlabinterval = ggproto("StatSlabinterval", AbstractStatSlabinterval,
         'i' = 'Instead of using {.arg slab_type}, use {.fun ggplot2::after_stat} to
           map the desired computed variable, e.g. {.code pdf} or {.code cdf}, onto
           an aesthetic, e.g. {.code aes(thickness = after_stat(pdf))}. Specifically:',
-        '*' = 'To replace {.code slab_type = "pdf"}, map {.code after_stat(pdf)} onto an aesthetic.',
-        '*' = 'To replace {.code slab_type = "cdf"}, map {.code after_stat(cdf)} onto an aesthetic.',
-        '*' = 'To replace {.code slab_type = "ccdf"}, map {.code after_stat(1 - cdf)} onto an aesthetic.',
-        '*' = 'To replace {.code slab_type = "histogram"}, map {.code after_stat(pdf)} onto an aesthetic and
+        '>' = 'To replace {.code slab_type = "pdf"}, map {.code after_stat(pdf)} onto an aesthetic.',
+        '>' = 'To replace {.code slab_type = "cdf"}, map {.code after_stat(cdf)} onto an aesthetic.',
+        '>' = 'To replace {.code slab_type = "ccdf"}, map {.code after_stat(1 - cdf)} onto an aesthetic.',
+        '>' = 'To replace {.code slab_type = "histogram"}, map {.code after_stat(pdf)} onto an aesthetic and
           pass {.code density = "histogram"} to the stat.',
         'i' = 'For more information, see the {.emph Computed Variables} section of {.fun ggdist::stat_slabinterval}.'
       ))
@@ -624,7 +631,7 @@ StatSlabinterval = ggproto("StatSlabinterval", AbstractStatSlabinterval,
       # dist aesthetic is not provided but x aesthetic is, and x is not a dist
       # this means we need to wrap it as a weighted dist_sample
       data = summarise_by(data, c("PANEL", y, "group"), function(d) {
-        data.frame(dist = .dist_weighted_sample(list(trans$inverse(d[[x]])), list(d[["weight"]])))
+        data_frame0(dist = .dist_weighted_sample(list(trans$inverse(d[[x]])), list(d[["weight"]])))
       })
       data[[x]] = median(data$dist)
     }
@@ -701,7 +708,7 @@ layer_slabinterval = function(...) {
             plot$scales$add(scale)
           }
           scale$limits = scale$limits %||% distr_levels(data[[dist]])
-          scale$train(posterior::draws_of(data[[dist]]))
+          scale$train(distr_levels(data[[dist]]))
         }
       }
       data
@@ -807,7 +814,6 @@ StatSlab = ggproto("StatSlab", StatSlabinterval,
   ), StatSlabinterval$layer_args),
 
   hidden_params = union(c(
-    "show_slab", "show_point", "show_interval",
     "point_interval", ".width"
   ), StatSlabinterval$hidden_params)
 )
